pub struct RemovalShipmentItem {
pub removal_shipment_item_id: Option<String>,
pub tax_collection_model: Option<String>,
pub fulfillment_network_sku: Option<String>,
pub quantity: Option<i32>,
pub revenue: Option<Box<Currency>>,
pub fee_amount: Option<Box<Currency>>,
pub tax_amount: Option<Box<Currency>>,
pub tax_withheld: Option<Box<Currency>>,
}Expand description
RemovalShipmentItem : Item-level information for a removal shipment.
Fields
removal_shipment_item_id: Option<String>An identifier for an item in a removal shipment.
tax_collection_model: Option<String>The tax collection model applied to the item. Possible values: * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller. * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.
fulfillment_network_sku: Option<String>The Amazon fulfillment network SKU for the item.
quantity: Option<i32>The quantity of the item.
revenue: Option<Box<Currency>>fee_amount: Option<Box<Currency>>tax_amount: Option<Box<Currency>>tax_withheld: Option<Box<Currency>>Implementations
sourceimpl RemovalShipmentItem
impl RemovalShipmentItem
sourcepub fn new() -> RemovalShipmentItem
pub fn new() -> RemovalShipmentItem
Item-level information for a removal shipment.